@@ -18,8 +18,8 @@
 
 #include "mainwindow.h"
 
-#include "bgselector.h"
-#include "customgame.h"
+#include "bgselectorconfig.h"
+#include "customgameconfig.h"
 #include "gameconfig.h"
 #include "gamescene.h"
 #include "gameview.h"
@@ -35,7 +35,6 @@
 #include <QInputDialog>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KNotifyConfigWidget>
 #include <KScoreDialog>
 #include <KStandardAction>
 #include <KStandardGameAction>
@@ -94,25 +93,22 @@ MainWindow::~MainWindow()
 {
 }
 
-void MainWindow::configureNotifications()
-{
-    KNotifyConfigWidget::configure( this );
-}
-
 void MainWindow::configureSettings()
 {
-    if ( KConfigDialog::showDialog( QStringLiteral( "settings" ) ) )
+    if ( KConfigDialog::showDialog( QStringLiteral( "settings" ) ) ) {
         return;
+    }
 
     KConfigDialog* dialog = new KConfigDialog( this, QStringLiteral( "settings" ), Settings::self() );
     dialog->addPage( new GameConfig( dialog ), i18n( "General" ), QStringLiteral( "games-config-options" ) );
     dialog->addPage( new KgThemeSelector( m_scene->themeProvider() ), i18n( "Theme" ), QStringLiteral( "games-config-theme" ) );
-    dialog->addPage( new BackgroundSelector( dialog ), i18n( "Background" ), QStringLiteral( "games-config-background" ) );
-    if ( !m_kSameMode )
+    dialog->addPage( new BgSelectorConfig( dialog ), i18n( "Background" ), QStringLiteral( "games-config-background" ) );
+    if ( !m_kSameMode ) {
         dialog->addPage( new CustomGameConfig( dialog ), i18n( "Custom Game" ), QStringLiteral( "games-config-custom" ) );
-    connect(m_scene->themeProvider(), SIGNAL(currentThemeChanged(const KgTheme*)), SLOT(loadSettings())); //setBackgroundType!
+    }
+
+    connect(m_scene->themeProvider(), &KgThemeProvider::currentThemeChanged, this, &MainWindow::loadSettings); //setBackgroundType!
     connect(dialog, &KConfigDialog::settingsChanged, this, &MainWindow::loadSettings);
-    //QT5 dialog->setHelp( QString(), QLatin1String( "klickety" ) );
     dialog->show();
 }
 
@@ -133,8 +129,9 @@ void MainWindow::loadSettings()
 
 void MainWindow::newGame( int gameId )
 {
-    if ( !confirmAbort() )
+    if ( !confirmAbort() ) {
         return;
+    }
 
     m_pauseAction->setChecked( false );
     m_pauseAction->setEnabled( true );
@@ -173,26 +170,29 @@ void MainWindow::newGame( int gameId )
 
 void MainWindow::newNumGame()
 {
-    if ( !confirmAbort() )
+    if ( !confirmAbort() ) {
         return;
+    }
 
     bool ok = false;
     int userGameId = QInputDialog::getInt( this, i18n( "Select Board" ),
                                                 i18n( "Select a board number:" ),
                                                 qrand(), 1, RAND_MAX, 1,
                                                 &ok );
-    if ( ok )
+    if ( ok ) {
         newGame( userGameId );
+    }
 }
 
 void MainWindow::pauseGame( bool isPaused )
 {
     m_scene->setPaused( isPaused );
     if ( !m_kSameMode ) {
-        if ( isPaused )
+        if ( isPaused ) {
             m_gameClock->pause();
-        else
+        } else {
             m_gameClock->resume();
+        }
     }
 }
 
@@ -215,8 +215,9 @@ void MainWindow::restartGame()
 void MainWindow::loadGame()
 {
     QString fileName = QFileDialog::getOpenFileName( this, QString(), QString() , i18n( "Klickety Game Files (*.klickety)" ) );
-    if ( fileName.isEmpty() || !confirmAbort() )
+    if ( fileName.isEmpty() || !confirmAbort() ) {
         return;
+    }
 
     m_pauseAction->setChecked( false );
     m_pauseAction->setEnabled( true );
@@ -228,8 +229,9 @@ void MainWindow::loadGame()
 void MainWindow::saveGame()
 {
     QString fileName = QFileDialog::getSaveFileName( this, QString(), QString(), i18n( "Klickety Game Files (*.klickety)" ) );
-    if ( fileName.isEmpty() )
+    if ( fileName.isEmpty() ) {
         return;
+    }
     KConfig config( fileName, KConfig::SimpleConfig );
     KConfigGroup group = config.group( "Savegame" );
     m_scene->saveGame( group );
@@ -314,8 +316,9 @@ void MainWindow::onGameOver( int remainCount )
         KScoreDialog::FieldInfo scoreInfo;
         scoreInfo[ KScoreDialog::Score ].setNum( m_gameScore );
 
-        if ( d->addScore( scoreInfo ) )
+        if ( d->addScore( scoreInfo ) != 0 ) {
             d->exec();
+}
         delete d;
         return;
     }
@@ -334,8 +337,9 @@ void MainWindow::onGameOver( int remainCount )
     scoreInfo[KScoreDialog::Custom2] = m_gameClock->timeString();
     // remainCount*10000000 is much bigger than a usual time seconds
     scoreInfo[KScoreDialog::Score].setNum( remainCount*10000000 + m_gameClock->seconds() );
-    if ( d->addScore( scoreInfo, KScoreDialog::LessIsMore ) != 0 )
+    if ( d->addScore( scoreInfo, KScoreDialog::LessIsMore ) != 0 ) {
         d->exec();
+    }
     delete d;
 }
 
@@ -361,6 +365,11 @@ void MainWindow::setupActions()
     actionCollection()->addAction( QStringLiteral( "game_new_numeric" ), m_newNumGameAction );
     connect(m_newNumGameAction, &QAction::triggered, this, &MainWindow::newNumGame);
 
+    KToggleAction * soundAction = new KToggleAction(QIcon::fromTheme(QStringLiteral("speaker")), i18n("Play Sounds"), this);
+    soundAction->setChecked(Settings::enableSounds());
+    actionCollection()->addAction(QStringLiteral("sounds"), soundAction);
+    connect(soundAction, &KToggleAction::triggered, this, &MainWindow::setSoundsEnabled);
+
     // move menu
     QAction * undoAction = KStandardGameAction::undo( m_scene, SLOT(undoMove()), actionCollection() );
     undoAction->setEnabled( false );
@@ -384,7 +393,6 @@ void MainWindow::setupActions()
 
     // settings menu
     KStandardAction::preferences( this, SLOT(configureSettings()), actionCollection() );
-    KStandardAction::configureNotifications( this, SLOT(configureNotifications()), actionCollection() );
 
     if ( m_kSameMode ) {
         Kg::difficulty()->addLevel(new KgDifficultyLevel(0,
@@ -406,3 +414,9 @@ void MainWindow::setupActions()
 
     setupGUI( QSize( 340, 510 ) );
 }
+
+void MainWindow::setSoundsEnabled( bool enabled )
+{
+    Settings::setEnableSounds( enabled );
+    Settings::self()->save();
+}
